Coverage for cc_modules/tests/cc_blob_tests.py: 38%

1"""

2 camcops_server/cc_modules/tests/cc_blob_tests.py

3

4===============================================================================

5

6 Copyright (C) 2012, University of Cambridge, Department of Psychiatry.

7 Created by Rudolf Cardinal (rnc1001@cam.ac.uk).

8

9 This file is part of CamCOPS.

10

11 CamCOPS is free software: you can redistribute it and/or modify

12 it under the terms of the GNU General Public License as published by

13 the Free Software Foundation, either version 3 of the License, or

14 (at your option) any later version.

15

16 CamCOPS is distributed in the hope that it will be useful,

17 but WITHOUT ANY WARRANTY; without even the implied warranty of

18 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the

19 GNU General Public License for more details.

20

21 You should have received a copy of the GNU General Public License

22 along with CamCOPS. If not, see <https://www.gnu.org/licenses/>.

23

24===============================================================================

25

26"""

27

28 from camcops_server.cc_modules.cc_blob import Blob

29 from camcops_server.cc_modules.cc_unittest import DemoDatabaseTestCase

30 from camcops_server.cc_modules.cc_xml import XmlElement

31

32

33# =============================================================================

34# Unit tests

35# =============================================================================

36

37

38 class BlobTests(DemoDatabaseTestCase):

39 """

40 Unit tests.

41 """

42

43 def test_blob(self) -> None:

44 self.announce("test_blob")

45 q = self.dbsession.query(Blob)

46 b = q.first() # type: Blob

47 assert b, "Missing BLOB in demo database!"

48 self.assertIsInstanceOrNone(b.get_rotated_image(), bytes)

49 self.assertIsInstance(b.get_img_html(), str)

50 self.assertIsInstance(b.get_xml_element(self.req), XmlElement)

51 self.assertIsInstance(b.get_data_url(), str)